@@ -10,7 +10,7 @@
 #'
 #'@return Four numbers - C1, C2, C3, C4.   
 #'
-#'@import ape geiger MASS phytools 
+#'@import ape geiger phytools 
 #'
 #'@export
 #'
@@ -41,8 +41,9 @@ convrat<-function(phyl,phendata,convtips)
 
 #Error checking
 
-if (class(phyl) != "phylo") 
-	stop("your tree must be class 'phylo.'")
+if (!inherits(phyl, "phylo")) {
+        stop("your tree must be class 'phylo'")
+    }
 
 if (nrow(phendata) != length(phyl$tip)) 
 	stop("your data matrix must have the same number of rows as tips in the tree.")
@@ -109,7 +110,8 @@ if(ntax>2) {
 	C3s<-c()
 	C4s<-c()
 
-	for (i in 1:ntax) {
+	for (i in 1:ntax) { 
+	#	for (i in 1:(ntax-1)) { #New code
 
 		j<-i+1
 
@@ -128,16 +130,16 @@ if(ntax>2) {
 			t1totalevolution<-0
 			t2totalevolution<-0
 
-			for (ii in 1:(dim(lineagepaths[[1]])[1]-1)) {
+			for (m in 1:dim(lineagepaths[[1]])[1]-1) {
 
-				branchdistance<-sqrt(sum(((lineagepaths[[1]][ii,]-lineagepaths[[1]][ii+1,])^2)))
+				branchdistance<-sqrt(sum(((lineagepaths[[1]][m,]-lineagepaths[[1]][m+1,])^2)))
 				t1totalevolution<-t1totalevolution+branchdistance
 
 				}
 
-			for (ii in 1:dim(lineagepaths[[2]])[1]-1) {
+			for (k in 1:dim(lineagepaths[[2]])[1]-1) {
 
-				branchdistance<-sqrt(sum(((lineagepaths[[2]][ii,]-lineagepaths[[2]][ii+1,])^2)))
+				branchdistance<-sqrt(sum(((lineagepaths[[2]][k,]-lineagepaths[[2]][k+1,])^2)))
 				t2totalevolution<-t2totalevolution+branchdistance
 
 				}
