@@ -33,8 +33,9 @@ convratsig<-function(phyl,phendata,convtips,nsim)
 
 #Error checking
 
-if (class(phyl) != "phylo")
-    stop("your tree must be class 'phylo.'")
+if (!inherits(phyl, "phylo")) {
+        stop("your tree must be class 'phylo'")
+    }
 
 if (nrow(phendata) != length(phyl$tip))
     stop("your data matrix must have the same number of rows as tips in the tree.")
