@@ -30,8 +30,9 @@ labelstonumbers<-function(phyl,tips)
 
 {
 
-if (class(phyl) != "phylo") 
-	stop("your tree must be class 'phylo.'")
+if (!inherits(phyl, "phylo")) {
+        stop("your tree must be class 'phylo'")
+    }
 
 newtips<-c()
 
